# EdFi.OdsApi.Sdk.Api.Identity.IdentitiesApi

All URIs are relative to *https://api-mi.doubleline.us:443/ods-pd3/Identity/v2/2023*

Method | HTTP request | Description
------------- | ------------- | -------------
[**IdentitiesV2Create**](IdentitiesApi.md#identitiesv2create) | **POST** /identities | Creates a new Unique Id for the given Identity information.
[**IdentitiesV2CreateResult**](IdentitiesApi.md#identitiesv2createresult) | **GET** /identities/createresult/{id} | Retrieve asynchronous create results from a previously created request.
[**IdentitiesV2EntityDirectCert**](IdentitiesApi.md#identitiesv2entitydirectcert) | **GET** /identities/directcert/entity | Get all Direct Certification Information for the entity of the calling client.
[**IdentitiesV2Link**](IdentitiesApi.md#identitiesv2link) | **POST** /identities/link | Link one Identity to another Identity.
[**IdentitiesV2LinkResult**](IdentitiesApi.md#identitiesv2linkresult) | **GET** /identities/linkresult/{id} | Retrieve asynchronous link results from a previously created request.
[**IdentitiesV2Result**](IdentitiesApi.md#identitiesv2result) | **GET** /identities/results/{id} | Retrieve asynchronous search results from a previously created request.
[**IdentitiesV2Search**](IdentitiesApi.md#identitiesv2search) | **POST** /identities/search | Lookup existing Unique Ids for a persons, or suggest possible matches.
[**IdentitiesV2SearchV2**](IdentitiesApi.md#identitiesv2searchv2) | **POST** /identities/searchv2 | Lookup existing Unique Ids for a persons, or suggest possible matches.
[**IdentitiesV2SnackPack**](IdentitiesApi.md#identitiesv2snackpack) | **POST** /identities/snackpack | Get Student Snack Pack for one or more students.
[**IdentitiesV2SnackPackExtended**](IdentitiesApi.md#identitiesv2snackpackextended) | **POST** /identities/snackpack/extended | Get Student Snack Pack (Extended) for one or more students.
[**IdentitiesV2StudentDirectCert**](IdentitiesApi.md#identitiesv2studentdirectcert) | **POST** /identities/directcert/student | Get Direct Certification Information for one or more students.


<a name="identitiesv2create"></a>
# **IdentitiesV2Create**
> string IdentitiesV2Create (IdentityCreateRequest request)

Creates a new Unique Id for the given Identity information.

Assumption here is that the user has verified that possible matches are not correct matches. Returns the created identity information along with the assigned Unique Id.

### Example
```csharp
using System;
using System.Diagnostics;
using EdFi.OdsApi.Sdk.Api.Identity;
using EdFi.OdsApi.Sdk.Client;
using EdFi.OdsApi.Sdk.Models.Identity;

namespace Example
{
    public class IdentitiesV2CreateExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new IdentitiesApi();
            var request = new IdentityCreateRequest(); // IdentityCreateRequest | Identity object to be created.

            try
            {
                // Creates a new Unique Id for the given Identity information.
                string result = apiInstance.IdentitiesV2Create(request);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling IdentitiesApi.IdentitiesV2Create: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**IdentityCreateRequest**](IdentityCreateRequest.md)| Identity object to be created. | 

### Return type

**string**

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json, text/json
 - **Accept**: application/json, text/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="identitiesv2createresult"></a>
# **IdentitiesV2CreateResult**
> IdentityCreateResponse IdentitiesV2CreateResult (string id)

Retrieve asynchronous create results from a previously created request.

### Example
```csharp
using System;
using System.Diagnostics;
using EdFi.OdsApi.Sdk.Api.Identity;
using EdFi.OdsApi.Sdk.Client;
using EdFi.OdsApi.Sdk.Models.Identity;

namespace Example
{
    public class IdentitiesV2CreateResultExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new IdentitiesApi();
            var id = id_example;  // string | The request ID provided by an asynchronous create request.

            try
            {
                // Retrieve asynchronous create results from a previously created request.
                IdentityCreateResponse result = apiInstance.IdentitiesV2CreateResult(id);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling IdentitiesApi.IdentitiesV2CreateResult: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **string**| The request ID provided by an asynchronous create request. | 

### Return type

[**IdentityCreateResponse**](IdentityCreateResponse.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json, text/json
 - **Accept**: application/json, text/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="identitiesv2entitydirectcert"></a>
# **IdentitiesV2EntityDirectCert**
> DirectCertInformationResult IdentitiesV2EntityDirectCert ()

Get all Direct Certification Information for the entity of the calling client.

### Example
```csharp
using System;
using System.Diagnostics;
using EdFi.OdsApi.Sdk.Api.Identity;
using EdFi.OdsApi.Sdk.Client;
using EdFi.OdsApi.Sdk.Models.Identity;

namespace Example
{
    public class IdentitiesV2EntityDirectCertExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new IdentitiesApi();

            try
            {
                // Get all Direct Certification Information for the entity of the calling client.
                DirectCertInformationResult result = apiInstance.IdentitiesV2EntityDirectCert();
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling IdentitiesApi.IdentitiesV2EntityDirectCert: " + e.Message );
            }
        }
    }
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**DirectCertInformationResult**](DirectCertInformationResult.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, text/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="identitiesv2link"></a>
# **IdentitiesV2Link**
> IdentityLinkResponse IdentitiesV2Link (IdentityLinkRequest request)

Link one Identity to another Identity.

Link one Identity to another Identity.

### Example
```csharp
using System;
using System.Diagnostics;
using EdFi.OdsApi.Sdk.Api.Identity;
using EdFi.OdsApi.Sdk.Client;
using EdFi.OdsApi.Sdk.Models.Identity;

namespace Example
{
    public class IdentitiesV2LinkExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new IdentitiesApi();
            var request = new IdentityLinkRequest(); // IdentityLinkRequest | Identity object to be linked.

            try
            {
                // Link one Identity to another Identity.
                IdentityLinkResponse result = apiInstance.IdentitiesV2Link(request);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling IdentitiesApi.IdentitiesV2Link: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**IdentityLinkRequest**](IdentityLinkRequest.md)| Identity object to be linked. | 

### Return type

[**IdentityLinkResponse**](IdentityLinkResponse.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json, text/json
 - **Accept**: application/json, text/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="identitiesv2linkresult"></a>
# **IdentitiesV2LinkResult**
> IdentityLinkResponse IdentitiesV2LinkResult (string id)

Retrieve asynchronous link results from a previously created request.

Retrieve asynchronous link results from a previously created request.

### Example
```csharp
using System;
using System.Diagnostics;
using EdFi.OdsApi.Sdk.Api.Identity;
using EdFi.OdsApi.Sdk.Client;
using EdFi.OdsApi.Sdk.Models.Identity;

namespace Example
{
    public class IdentitiesV2LinkResultExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new IdentitiesApi();
            var id = id_example;  // string | The request ID provided by an asynchronous link request.

            try
            {
                // Retrieve asynchronous link results from a previously created request.
                IdentityLinkResponse result = apiInstance.IdentitiesV2LinkResult(id);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling IdentitiesApi.IdentitiesV2LinkResult: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **string**| The request ID provided by an asynchronous link request. | 

### Return type

[**IdentityLinkResponse**](IdentityLinkResponse.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json, text/json
 - **Accept**: application/json, text/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="identitiesv2result"></a>
# **IdentitiesV2Result**
> IdentitySearchResponse IdentitiesV2Result (string id)

Retrieve asynchronous search results from a previously created request.

### Example
```csharp
using System;
using System.Diagnostics;
using EdFi.OdsApi.Sdk.Api.Identity;
using EdFi.OdsApi.Sdk.Client;
using EdFi.OdsApi.Sdk.Models.Identity;

namespace Example
{
    public class IdentitiesV2ResultExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new IdentitiesApi();
            var id = id_example;  // string | The search token provided by a Find or Search request.

            try
            {
                // Retrieve asynchronous search results from a previously created request.
                IdentitySearchResponse result = apiInstance.IdentitiesV2Result(id);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling IdentitiesApi.IdentitiesV2Result: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **string**| The search token provided by a Find or Search request. | 

### Return type

[**IdentitySearchResponse**](IdentitySearchResponse.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, text/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="identitiesv2search"></a>
# **IdentitiesV2Search**
> IdentitySearchResponse IdentitiesV2Search (List<IdentitySearchRequest> criteria)

Lookup existing Unique Ids for a persons, or suggest possible matches.

### Example
```csharp
using System;
using System.Diagnostics;
using EdFi.OdsApi.Sdk.Api.Identity;
using EdFi.OdsApi.Sdk.Client;
using EdFi.OdsApi.Sdk.Models.Identity;

namespace Example
{
    public class IdentitiesV2SearchExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new IdentitiesApi();
            var criteria = new List<IdentitySearchRequest>(); // List<IdentitySearchRequest> | One or more identity search request objects.

            try
            {
                // Lookup existing Unique Ids for a persons, or suggest possible matches.
                IdentitySearchResponse result = apiInstance.IdentitiesV2Search(criteria);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling IdentitiesApi.IdentitiesV2Search: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **criteria** | [**List&lt;IdentitySearchRequest&gt;**](IdentitySearchRequest.md)| One or more identity search request objects. | 

### Return type

[**IdentitySearchResponse**](IdentitySearchResponse.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json, text/json
 - **Accept**: application/json, text/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="identitiesv2searchv2"></a>
# **IdentitiesV2SearchV2**
> IdentitySearchResponse IdentitiesV2SearchV2 (IdentitySearchRequestV2 criteria)

Lookup existing Unique Ids for a persons, or suggest possible matches.

### Example
```csharp
using System;
using System.Diagnostics;
using EdFi.OdsApi.Sdk.Api.Identity;
using EdFi.OdsApi.Sdk.Client;
using EdFi.OdsApi.Sdk.Models.Identity;

namespace Example
{
    public class IdentitiesV2SearchV2Example
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new IdentitiesApi();
            var criteria = new IdentitySearchRequestV2(); // IdentitySearchRequestV2 | The identity search request object.

            try
            {
                // Lookup existing Unique Ids for a persons, or suggest possible matches.
                IdentitySearchResponse result = apiInstance.IdentitiesV2SearchV2(criteria);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling IdentitiesApi.IdentitiesV2SearchV2: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **criteria** | [**IdentitySearchRequestV2**](IdentitySearchRequestV2.md)| The identity search request object. | 

### Return type

[**IdentitySearchResponse**](IdentitySearchResponse.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json, text/json
 - **Accept**: application/json, text/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="identitiesv2snackpack"></a>
# **IdentitiesV2SnackPack**
> StudentSnackPacksResult IdentitiesV2SnackPack (List<string> criteria)

Get Student Snack Pack for one or more students.

### Example
```csharp
using System;
using System.Diagnostics;
using EdFi.OdsApi.Sdk.Api.Identity;
using EdFi.OdsApi.Sdk.Client;
using EdFi.OdsApi.Sdk.Models.Identity;

namespace Example
{
    public class IdentitiesV2SnackPackExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new IdentitiesApi();
            var criteria = ;  // List<string> | The unique IDs of students being requested.

            try
            {
                // Get Student Snack Pack for one or more students.
                StudentSnackPacksResult result = apiInstance.IdentitiesV2SnackPack(criteria);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling IdentitiesApi.IdentitiesV2SnackPack: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **criteria** | **List&lt;string&gt;**| The unique IDs of students being requested. | 

### Return type

[**StudentSnackPacksResult**](StudentSnackPacksResult.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json, text/json
 - **Accept**: application/json, text/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="identitiesv2snackpackextended"></a>
# **IdentitiesV2SnackPackExtended**
> StudentSnackPacksExtendedResult IdentitiesV2SnackPackExtended (StudentSnackPackExtendedRequest criteria)

Get Student Snack Pack (Extended) for one or more students.

### Example
```csharp
using System;
using System.Diagnostics;
using EdFi.OdsApi.Sdk.Api.Identity;
using EdFi.OdsApi.Sdk.Client;
using EdFi.OdsApi.Sdk.Models.Identity;

namespace Example
{
    public class IdentitiesV2SnackPackExtendedExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new IdentitiesApi();
            var criteria = new StudentSnackPackExtendedRequest(); // StudentSnackPackExtendedRequest | The unique IDs of students being requested and the version of the CEPI result to return.

            try
            {
                // Get Student Snack Pack (Extended) for one or more students.
                StudentSnackPacksExtendedResult result = apiInstance.IdentitiesV2SnackPackExtended(criteria);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling IdentitiesApi.IdentitiesV2SnackPackExtended: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **criteria** | [**StudentSnackPackExtendedRequest**](StudentSnackPackExtendedRequest.md)| The unique IDs of students being requested and the version of the CEPI result to return. | 

### Return type

[**StudentSnackPacksExtendedResult**](StudentSnackPacksExtendedResult.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json, text/json
 - **Accept**: application/json, text/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="identitiesv2studentdirectcert"></a>
# **IdentitiesV2StudentDirectCert**
> StudentDirectCertInformationResult IdentitiesV2StudentDirectCert (List<string> criteria)

Get Direct Certification Information for one or more students.

### Example
```csharp
using System;
using System.Diagnostics;
using EdFi.OdsApi.Sdk.Api.Identity;
using EdFi.OdsApi.Sdk.Client;
using EdFi.OdsApi.Sdk.Models.Identity;

namespace Example
{
    public class IdentitiesV2StudentDirectCertExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new IdentitiesApi();
            var criteria = ;  // List<string> | The unique IDs of students being requested.

            try
            {
                // Get Direct Certification Information for one or more students.
                StudentDirectCertInformationResult result = apiInstance.IdentitiesV2StudentDirectCert(criteria);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling IdentitiesApi.IdentitiesV2StudentDirectCert: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **criteria** | **List&lt;string&gt;**| The unique IDs of students being requested. | 

### Return type

[**StudentDirectCertInformationResult**](StudentDirectCertInformationResult.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json, text/json
 - **Accept**: application/json, text/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

